@@ -1,4 +1,11 @@
-from .__core__ import PyotCore
+
+from typing import TYPE_CHECKING
+
+from pyot.conf.model import models
+from .base import PyotCore
+
+if TYPE_CHECKING:
+    from .summoner import Summoner
 
 
 class ThirdPartyCode(PyotCore):
@@ -8,10 +15,10 @@ class ThirdPartyCode(PyotCore):
     class Meta(PyotCore.Meta):
         rules = {"third_party_code_v4_code": ["summoner_id"]}
 
-    def __init__(self, summoner_id: str = None, platform: str = None):
-        self._lazy_set(locals())
+    def __init__(self, summoner_id: str = None, platform: str = models.lol.DEFAULT_PLATFORM):
+        self.initialize(locals())
 
-    def _transform(self, data):
+    def transform(self, data):
         new_data = {}
         new_data["code"] = data
         return new_data
