@@ -2,7 +2,6 @@ from typing import List, Iterator, TYPE_CHECKING
 from datetime import datetime, timedelta
 
 from pyot.conf.model import models
-from pyot.core.functional import parse_camelcase
 from .base import PyotCore, PyotStatic
 
 if TYPE_CHECKING:
@@ -163,8 +162,8 @@ class MatchHistory(PyotCore):
         self.initialize(locals())
 
     def query(self, count: int = 20):
-        '''Query parameters setter.'''
-        self._meta.query = parse_camelcase(locals())
+        '''Set query request parameters.'''
+        super()._place_query(locals())
         return self
 
     @property
